proc CreateFiles { startDir namePat key pretty lastname firstnames email inst url date} {
    set pwd [pwd]
    if [catch {cd $startDir} err] {
	puts "ERROR $err"
	return
    }
    foreach file [glob -nocomplain *] {
	if [file isdirectory $file] {
	    CreateFiles $file $namePat $key $pretty $lastname $firstnames $email $inst $url $date
	} else {
	    if {[regsub -all {foo} $file $key newFile]} {
		puts "Creating \t$newFile"
		if [catch {file rename "$pwd/$startDir/$file" "$pwd/$startDir/$newFile"} err] {
		    puts "ERROR $err"
		    return
		} else {
		    #First we read each template
		    set fileId [open "$pwd/$startDir/$newFile" r 0600]
		    set content [read $fileId]
		    close $fileId

		    #Now replace all placeholders
		    regsub -all {foo} $content $key content
		    regsub -all {Foo} $content $pretty content
		    regsub -all {YourName} $content "$firstnames $lastname" content
		    regsub -all {test@test.com} $content $email content
		    regsub -all {YourInstitution} $content $inst content
		    regsub -all {InstitutionURL} $content $url content
		    regsub -all {yyyy-mm-dd} $content $date content

		    #Finally we replace templates
		    set fileId [open "$pwd/$startDir/$newFile" w 0600]
		    puts $fileId $content
		    close $fileId
		}
	    }
	}
    }
    cd $pwd
}

puts "===================================================="
puts "dotLRN Integration Support"
puts "----------------------------------------------------"
puts "Note: You need a clean copy of the integration" 
puts "      package each time you run this script."
puts "      This service assumes that you have already"
puts "      created a package and want to integrate it"
puts "      with dotLRN."
puts "----------------------------------------------------"
puts "Enter the package key (no white-space): "
set KEY [gets stdin]
puts  "The pretty name for your package     : "
set PRETTY [gets stdin]
puts  "Your lastname                        : "
set LASTNAME [gets stdin]
puts  "Your first names                     : "
set FIRSTNAMES [gets stdin]
puts  "Your email                           : "
set EMAIL [gets stdin]
puts  "Your Institution                     : "
set INSTITUTION [gets stdin]
puts  "$INSTITUTION's URL (http://...)"
set URL [gets stdin]
puts "----------------------------------------------------"
puts "Thank you $FIRSTNAMES $LASTNAME"
puts "for using the integration support."
puts "Two packages will be created for the package"
puts "$PRETTY ($KEY)."

set DATE [clock format [clock seconds] -format %Y-%m-%d]
puts "----------------------------------------------------"
puts "Creating Package $KEY-portlet..."
CreateFiles foo-portlet foo $KEY $PRETTY $LASTNAME $FIRSTNAMES $EMAIL $INSTITUTION $URL $DATE
file rename foo-portlet "$KEY-portlet"
puts "done."
puts "----------------------------------------------------"
puts "Creating Package dotlrn-$KEY..."
CreateFiles dotlrn-foo foo $KEY $PRETTY $LASTNAME $FIRSTNAMES $EMAIL $INSTITUTION $URL $DATE
file rename dotlrn-foo "dotlrn-$KEY"
puts "done."
puts "----------------------------------------------------"
puts "Finished!"
puts "----------------------------------------------------"
puts "Copy the packages to your OpenACS packages folder" 
puts "and use the Package Manager for installation."
puts "\nAuthor: Nima Mazloumi, 2005"
puts "===================================================="